==> marray_1.24.0.zip: marray/doc/marrayInput.R <==
###################################################
### chunk number 1: 
###################################################
library(marray)
data(swirl)


###################################################
### chunk number 2: 
###################################################
datadir <- system.file("swirldata", package="marray")
dir(datadir)


###################################################
### chunk number 3: 
###################################################
swirlTargets <- read.marrayInfo(file.path(datadir, "SwirlSample.txt"))
summary(swirlTargets)


###################################################
### chunk number 4: 
###################################################
galinfo <- read.Galfile("fish.gal", path=datadir) 
names(galinfo)


###################################################
### chunk number 5: 
###################################################
swirl.gnames <- read.marrayInfo(file.path(datadir, "fish.gal"),
info.id=4:5, labels=5, skip=21) 
summary(swirl.gnames) 


###################################################
### chunk number 6: 
###################################################
swirl.layout <- read.marrayLayout(fname=file.path(datadir, "fish.gal"),
                                  ngr=4, ngc=4, nsr=22, nsc=24,
                                  skip=21,ctl.col=4)
ctl<-rep("Control",maNspots(swirl.layout))
ctl[maControls(swirl.layout)!="control"]  <- "probes"
maControls(swirl.layout)<-factor(ctl)
summary(swirl.layout)


###################################################
### chunk number 7: 
###################################################
mraw <- read.Spot(path=datadir, 
                  layout=galinfo$layout, 
                  gnames=galinfo$gnames, 
                  target=swirlTargets)
summary(mraw)

==> marray_1.28.0.zip: marray/doc/marrayInput.R <==
###################################################
### chunk number 1: 
###################################################
#line 121 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
library(marray)
data(swirl)


###################################################
### chunk number 2: 
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
datadir <- system.file("swirldata", package="marray")
dir(datadir)


###################################################
### chunk number 3: 
###################################################
#line 184 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
swirlTargets <- read.marrayInfo(file.path(datadir, "SwirlSample.txt"))
summary(swirlTargets)


###################################################
### chunk number 4: 
###################################################
#line 204 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
galinfo <- read.Galfile("fish.gal", path=datadir) 
names(galinfo)


###################################################
### chunk number 5: 
###################################################
#line 246 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
swirl.gnames <- read.marrayInfo(file.path(datadir, "fish.gal"),
info.id=4:5, labels=5, skip=21) 
summary(swirl.gnames) 


###################################################
### chunk number 6: 
###################################################
#line 256 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
swirl.layout <- read.marrayLayout(fname=file.path(datadir, "fish.gal"),
                                  ngr=4, ngc=4, nsr=22, nsc=24,
                                  skip=21,ctl.col=4)
ctl<-rep("Control",maNspots(swirl.layout))
ctl[maControls(swirl.layout)!="control"]  <- "probes"
maControls(swirl.layout)<-factor(ctl)
summary(swirl.layout)


###################################################
### chunk number 7: 
###################################################
#line 279 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayInput.Rnw"
mraw <- read.Spot(path=datadir, 
                  layout=galinfo$layout, 
                  gnames=galinfo$gnames, 
                  target=swirlTargets)
summary(mraw)
